==> digiclockwdg_0.2.5-1.tar.gz: digiclockwdg-0.2.5/digiclock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <location filename="digitalclockwdg.cpp" line="24"/>
        <source>Digital Clock Widget</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="14"/>
        <source>Digital Clock settings</source>
        <translation>Paramètres de DigiClock</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="24"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="48"/>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="72"/>
        <source>Digits Color</source>
        <translation>Couleur des chiffres</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="93"/>
        <source>Show seconds</source>
        <translation>Secondes</translation>
    </message>
    <message>
        <source>Time Format</source>
        <translation>Format d&apos;heure</translation>
    </message>
    <message>
        <source>24H</source>
        <translation>24 Heures</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation>12 Heures (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation>Militaire</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation>Défaut (LCD)</translation>
    </message>
    <message>
        <source>B</source>
        <translation>Gras</translation>
    </message>
    <message>
        <source>I</source>
        <translation>Italique</translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation>A propos de DigiClock</translation>
    </message>
    <message>
        <source>12:48</source>
        <translation></translation>
    </message>
    <message>
        <source>Blinking Delimiter</source>
        <translation>Faire clignoter les :</translation>
    </message>
    <message>
        <source>&lt;b&gt;DigiClock&lt;/b&gt; 0.2.5&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing digital time</source>
        <translation>&lt;b&gt;DigiClock&lt;/b&gt; 0.2.5&lt;br&gt;Utilise &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Widget sur le bureau  qui affiche l&apos;heure en format digital</translation>
    </message>
</context>
</TS>

==> digiclockwdg_0.3.0.tar.gz: digiclockwdg-0.3.0/digiclock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation>Paramètres de DigiClock</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation>Couleur des chiffres</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>Secondes</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>24H</source>
        <translation>24 Heures</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation>12 Heures (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation>Militaire</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation>Défaut (LCD)</translation>
    </message>
    <message>
        <source>B</source>
        <translation>Gras</translation>
    </message>
    <message>
        <source>I</source>
        <translation>Italique</translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation>A propos de DigiClock</translation>
    </message>
    <message>
        <source>12:48</source>
        <translation></translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing digital time</source>
        <translation>&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Utilise &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Widget sur le bureau  qui affiche l&apos;heure en format digital</translation>
    </message>
</context>
</TS>
